/* Stringtable for Admin Console User Interface */
var l10nstrings = {};

l10nstrings.strProductName = 'LibreOffice Online';
l10nstrings.strAdminConsole = _('Admin console');
l10nstrings.strSettings = _('Settings');
l10nstrings.strOverview = _('Overview');
l10nstrings.strCurrent = _('(current)');
l10nstrings.strAnalytics = _('Analytics');
l10nstrings.strHistory = _('History');
l10nstrings.strDashboard = _('Dashboard');
l10nstrings.strUsersOnline = _('Users online');
l10nstrings.strUserName = _('User Name');
l10nstrings.strDocumentsOpened = _('Documents opened');
l10nstrings.strDocumentNumber = _('Number of Documents');
l10nstrings.strMemoryConsumed = _('Memory consumed');
l10nstrings.strSentBytes = _('Bytes sent');
l10nstrings.strRecvBytes = _('Bytes received');
l10nstrings.strPid = _('PID');
l10nstrings.strDocument = _('Document');
l10nstrings.strNumberOfViews = _('Number of views');
l10nstrings.strElapsedTime = _('Elapsed time');
l10nstrings.strIdleTime = _('Idle time');
l10nstrings.strModified = _('Modified');
l10nstrings.strKill = _('Kill');
l10nstrings.strGraphs = _('Graphs');
l10nstrings.strMemoryGraph = _('Memory Graph');
l10nstrings.strCpuGraph = _('CPU Graph');
l10nstrings.strNetGraph = _('Network Graph');
l10nstrings.strSave = _('Save');
l10nstrings.strMemoryStatsCachesize = _('Cache size of memory statistics');
l10nstrings.strMemoryStatsInterval = _('Time interval of memory statistics (in ms)');
l10nstrings.strCpuStatsCachesize = _('Cache size of CPU statistics');
l10nstrings.strCpuStatsInterval = _('Time interval of CPU statistics (in ms)');
l10nstrings.strLimitVirtMemMb = _('Maximum Document process virtual memory (in MB) - reduce only');
l10nstrings.strLimitStackMemKb = _('Maximum Document process stack memory (in KB) - reduce only');
l10nstrings.strLimitFileSizeMb = _('Maximum file size allowed to write to disk (in MB) - reduce only');
l10nstrings.strDocuments = _('Documents:');
l10nstrings.strExpired = _('Expired:');
l10nstrings.strRefresh = _('Refresh');

if (module) {
	module.exports = l10nstrings;
}
